#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeSnippet = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const recursive_readdir_1 = __importDefault(require("recursive-readdir"));
const enums_1 = require("./enums");
const utils_1 = require("./utils");
class CodeSnippet {
    snippet;
    config;
    prompt;
    args;
    constructor() {
        this.snippet = new utils_1.UtilSnippet();
        this.prompt = new utils_1.UtilPrompt();
        this.config = new utils_1.UtilConfig().generate();
        this.args = {
            snippet: '',
            name: '',
            path: '',
        };
    }
    async start() {
        try {
            const args = await this.prompt.getArgs();
            this.args = { ...this.args, ...args };
            const config = this.config.find(({ snippet }) => snippet === this.args.snippet);
            if (!config)
                throw new Error('config');
            if (this.args.snippet === '')
                throw new Error(`specify the required argument --snippet=example`);
            if (this.args.name === '')
                throw new Error(`specify the required argument --name=example`);
            if (this.args.path === '')
                throw new Error(`specify the required argument --path=example`);
            (0, recursive_readdir_1.default)(config.files, (error, files) => {
                if (error)
                    throw new Error(error.message);
                files.forEach((file) => {
                    const snippet = JSON.stringify(fs_1.default.readFileSync(file, 'utf-8'));
                    const data = this.snippet.replace(snippet, this.args.name);
                    const fileName = path_1.default.basename(file).replaceAll(enums_1.enumSnippetName.lowerKebabCase, this.args.name);
                    const mkdirPath = path_1.default.join(...[
                        path_1.default
                            .dirname(file)
                            .replaceAll(path_1.default.join(config.files), path_1.default.join(...[this.args.path, this.args.name])),
                    ]);
                    const writeFilePath = path_1.default.join(...[mkdirPath, path_1.default.basename(file).replaceAll(enums_1.enumSnippetName.lowerKebabCase, this.args.name)]);
                    if (fs_1.default.existsSync(writeFilePath))
                        throw new Error(this.args.name);
                    fs_1.default.mkdirSync(mkdirPath, { recursive: true });
                    fs_1.default.writeFileSync(writeFilePath, JSON.parse(data));
                    // eslint-disable-next-line no-console
                    console.log(`${chalk_1.default.green(`√`)} ${chalk_1.default.gray(`${fileName}`)}`);
                });
            });
        }
        catch (e) {
            // eslint-disable-next-line no-console
            console.log(chalk_1.default.red(e));
        }
    }
}
exports.CodeSnippet = CodeSnippet;
const codeSnippet = new CodeSnippet();
codeSnippet.start();
//# sourceMappingURL=index.js.map